# also_anomaly_detector

Attribute-wise Learning for Scoring Outliers (ALSO) is an unsupervised anomaly detection algorithm for multidimensional data.

## Description

Python implementation of ALSO. ALSO, or _Attribute-wise Learning for Scoring Outliers_, is an unsupervised anomaly detection algorithm for multidimensional data as described in Paulheim, H., Meusel, R. A decomposition of the outlier detection problem into a set of supervised learning problems. Mach Learn 100, 509–531 (2015). https://doi.org/10.1007/s10994-015-5507-y

I am not the author, nor in any way affiliated with the authors of the paper above. This is an independent python implementation of the ALSO-approach.

## Usage

For a local install, `cd` to the root of this repository and simply; 

```
python setup.py develop
```

## Documentation

Documentation should be available at [https://eliavw.github.io/also_anomaly_detector](https://eliavw.github.io/also_anomaly_detector).

## Administration

Open the folder [note/deploy](./note/deploy) for notebooks that contain annotated scripts for the different administrative tasks you may want to undertake with this software project.
